@@ -67,7 +67,7 @@ $target %dowhat readsweeps $max_processes $computype $calcprocedure %specularrat
 toil genstar solvestar integratebox filterbox__ clean
 );
 
-$VERSION = '0.171';
+$VERSION = '0.173';
 $ABSTRACT = 'Sim::OPT is an optimization and parametric exploration program oriented to problem decomposition. It can be used with simulation programs receiving text files as input and emitting text files as output. It allows a free mix of sequential and parallel block coordinate searches.';
 
 #################################################################################
@@ -586,7 +586,7 @@ sub extractcase #  UPDATES THE FILE NAME ON THE BASIS OF A %carrier
 	}
 
 	#say $tee "In extractcase, OBTAINED \%carrier: " . dump( \%carrier ) ;
-	my %to = %{ makefilename( \%tempc, $mypath, $file, $instn, \%inst ) }; say $tee "In extractcase!, RESULT1:; \%to: " . dump( \%to ) ;
+	my %to = %{ makefilename( \%tempc, $mypath, $file, $instn, \%inst ) }; #say $tee "In extractcase!, RESULT1:; \%to: " . dump( \%to ) ;
 	return( \%to );
 }
 
@@ -1595,8 +1595,8 @@ sub setlaunch # IT SETS THE DATA FOR THE SEARCH ON THE ACTIVE BLOCK.
 		#say $tee "IN SETLAUNCH \%inst" . dump( \%inst );
 
 
-		#unless( $to{cleanto} ~~ @{ $dirfiles{dones} } )
-		#{
+		unless( ( $to{cleanto} ~~ @{ $dirfiles{dones} } ) and ( $dirfiles{precomputed} eq "" ))
+		{
 			push( @{ $dirfiles{dones} }, $to{cleanto} );
 			$inst{$to{cleanto}} = $to{crypto};
 			$inst{$to{crypto}} = $to{cleanto};
@@ -1622,7 +1622,7 @@ sub setlaunch # IT SETS THE DATA FOR THE SEARCH ON THE ACTIVE BLOCK.
 				instn => $instn, inst => \%inst
 			} );
 			$instn++;
-		#}
+		}
 		$count++;
 	} #say $tee "IN SETLAUNCH \@instances " . dump( @instances );
 	exe( { instances => \@instances, dirfiles => \%dirfiles } );
